@@ -46,8 +46,25 @@ swing = [
 	]
 
 weird = [
+	SlowStridePianist({'channel': 1, 'start': 4}),
+	ChromaticSoloist({'channel': 2, 'midi_instr': 108, 'start': 0, 'step': 4}),
+	ChromaticSoloist({'channel': 3, 'midi_instr': 30, 'start': 2, 'end': 8, 'step': 2}),
+	BassInstrument({'channel':4, 'midi_instr':36, 'let_ring': True, 'start': 6}),
+	SoloInstrument({'channel':5, 'midi_instr':41, 'start': 6, 'end': 8, 'step': 6}),
+	ChordInstrument({'channel':6, 'chance': 0.25, 'max_velocity': 70, 'midi_instr': 10, 'start': 0, 'step': 4}), 
+	RockDrum({'start': 8, 'step': 8}),
+	JazzDrum({'start': 0, 'step': 8}),
+	]
 
-	ChromaticSoloist({'channel': 2})
+soothing = [
+	SoloInstrument({'channel': 3, 'midi_instr': 25, 'start': 4, 'end': 8, 'step': 4}),
+	WalkingBass({'channel':4, 'midi_instr':35, 'let_ring': True, 'start': 0}),
+	ChordInstrument({'channel':5, 'chance': 0.25, 'max_velocity': 70, 'midi_instr': 6, 'start': 0, 'step': 4}), 
+	ChromaticSoloist({'channel': 6, 'midi_instr': 21, 'start': 8, 'end': 12, 'step': 4}),
+	PowerChords({'channel': 7, 'midi_instr': 30, 'start': 8, 'end': 12, 'step': 4}),
+	FastStridePianist({'channel': 8, 'midi_instr': 1, 'max_velocity': 80, 'start': 20, 'step': 4}),
+	RockDrum({'start': 4}),
+	
 	]
 
 boogie = [
@@ -74,3 +91,9 @@ jazz = [
 	SoloInstrument({'midi_instr': 11, 'channel': 11, 'start': 0, 'step': 4}),
 	SoloInstrument({'midi_instr': 66,'channel': 15, 'start': 4, 'stop': 8, 'step': 4, 'max_velocity': 80}),
 	]
+
+jazz2 = [
+	ChromaticSoloist({'channel': 0, 'midi_instr': randrange(20,100)}),
+	FastStridePianist({'channel': 5, 'start':0}),
+
+	]
