@@ -8,7 +8,7 @@ class Instrument:
 	params = {}
 
 	
-	playing = None
+	playing = []
 	last_played = []
 	last_chan= 0
 
@@ -38,9 +38,10 @@ class Instrument:
 		if 'let_ring' not in self.params:
 			self.stop_playing_notes()
 		else:
-			if not self.params["let_ring"]:
+			if not self.params['let_ring']:
 				self.stop_playing_notes()
 
+
 		if 'channel' in self.params:
 			n = self.generate_note(state)
 			v = self.generate_velocity(state)
@@ -48,7 +49,7 @@ class Instrument:
 				fluidsynth.play_NoteContainer(n, v, \
 					self.params["channel"])
 				self.last_chan = self.params["channel"]
-				self.playing = n
+				self.playing += n
 				self.last_played = n
 				if state["paint_function"] != None:
 					state["paint_function"](n, self.params["channel"])
@@ -76,7 +77,6 @@ class Instrument:
 
 
 	def stop_playing_notes(self):
-		if self.playing != None:
-			fluidsynth.stop_NoteContainer(self.playing, \
+		fluidsynth.stop_NoteContainer(self.playing,
 				self.last_chan)
-			self.playing = None
+		self.playing = []
